Index: /trunk/MagicSoft/Mars/mcalib/MHCalibrationBlindPixel.cc
===================================================================
--- /trunk/MagicSoft/Mars/mcalib/MHCalibrationBlindPixel.cc	(revision 2837)
+++ /trunk/MagicSoft/Mars/mcalib/MHCalibrationBlindPixel.cc	(revision 2838)
@@ -71,5 +71,5 @@
     fMeanTime(0.),  fMeanTimeErr(0.), fSigmaTime(0.), fSigmaTimeErr(0.),
     fLambdaCheck(0.), fLambdaCheckErr(0.),
-    fgSinglePheFitFunc(&gfKto4),fgSinglePheFitNPar(6)
+    fgSinglePheFitFunc(&fKto4),fgSinglePheFitNPar(6)
     
 {
@@ -364,5 +364,5 @@
   //
   // Normalize the histogram to facilitate faster fitting of the area
   // For speed reasons, gfKto4 is normalized to Sqrt(2 pi).
   // Therefore also normalize the histogram to that value 
   //
@@ -364,5 +364,5 @@
   //
   // Normalize the histogram to facilitate faster fitting of the area
-  // For speed reasons, gfKto4 is normalized to Sqrt(2 pi).
+  // For speed reasons, fKto4 is normalized to Sqrt(2 pi).
   // Therefore also normalize the histogram to that value 
   //
